{% extends 'corphandouts/base.html' %}
{% load i18n %}
{% load static %}
{% block details %}
    <div class="panel panel-default" style="max-width:900px;">
        <div class="panel-heading">
            <h3 class="panel-title">{{ title }}</h3>
        </div>
        <div class="panel-body">{% include content_file %}</div>
    </div>
{% endblock %}
